==> devextreme-21.1.1-alpha-21089-0329.tgz: package/cjs/renovation/ui/scheduler/workspaces/base/group_panel/group_panel.j.js <==
/**
 * DevExtreme (cjs/renovation/ui/scheduler/workspaces/base/group_panel/group_panel.j.js)
 * Version: 21.1.0 (build 21089-0329)
 * Build date: Tue Mar 30 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../component_wrapper/component"));
var _group_panel = require("./group_panel");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var GroupPanel = function(_BaseComponent) {
    _inheritsLoose(GroupPanel, _BaseComponent);

    function GroupPanel() {
        return _BaseComponent.apply(this, arguments) || this
    }
    var _proto = GroupPanel.prototype;
    _proto.getProps = function() {
        var props = _BaseComponent.prototype.getProps.call(this);
        props.resourceCellTemplate = this._createTemplateComponent(props, props.resourceCellTemplate);
        return props
    };
    _createClass(GroupPanel, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["resourceCellTemplate"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _group_panel.GroupPanel
        }
    }]);
    return GroupPanel
}(_component.default);
exports.default = GroupPanel;
(0, _component_registrator.default)("dxGroupPanel", GroupPanel);
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-21.2.1-alpha-21200-0321.tgz: package/cjs/renovation/ui/scheduler/workspaces/base/group_panel/group_panel.j.js <==
/**
 * DevExtreme (cjs/renovation/ui/scheduler/workspaces/base/group_panel/group_panel.j.js)
 * Version: 21.2.0 (build 21200-0321)
 * Build date: Mon Jul 19 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../component_wrapper/common/component"));
var _group_panel = require("./group_panel");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var GroupPanel = function(_BaseComponent) {
    _inheritsLoose(GroupPanel, _BaseComponent);

    function GroupPanel() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(GroupPanel, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["resourceCellTemplate"],
                props: ["groups", "groupOrientation", "groupByDate", "height", "baseColSpan", "columnCountPerGroup", "className", "resourceCellTemplate"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _group_panel.GroupPanel
        }
    }]);
    return GroupPanel
}(_component.default);
exports.default = GroupPanel;
(0, _component_registrator.default)("dxGroupPanel", GroupPanel);
module.exports = exports.default;
module.exports.default = exports.default;
